# -*- coding: utf-8 -*-
import io
import logging
from typing import Union

from django.http import HttpResponse
from trench.backends.application import ApplicationMessageDispatcher
from trench.responses import DispatchResponse, FailedDispatchResponse

from thx.mfa.utils import generate_qrcode


class QRCodeApplicationMessageDispatcher(ApplicationMessageDispatcher):
    def dispatch_message(self) -> Union[DispatchResponse, HttpResponse]:
        try:
            qr_link = self._create_qr_link(self._mfa_method.user)
            buffer = io.BytesIO()
            generate_qrcode(qr_link, buffer)
            buffer.seek(0)
            return HttpResponse(buffer.read(), content_type="image/png")
        except Exception as cause:
            logging.error(cause, exc_info=True)
            return FailedDispatchResponse(details=str(cause))
