# -*- coding: utf-8 -*-
from drf_spectacular.utils import OpenApiExample, extend_schema, inline_serializer
from rest_framework import serializers
from trench.views import (
    MFAMethodActivationView as _MFAMethodActivationView,
    MFAMethodConfirmActivationView as _MFAMethodConfirmActivationView,
    MFAMethodDeactivationView as _MFAMethodDeactivationView,
)
from trench.views.jwt import MFAFirstStepJWTView as _MFAFirstStepJWTView

# TODO: gestire API DOC per tutte le altre viste:
#  codes/regenerate
#  code/request
#  login/code
#  change-primary-method
#  config
#  user-active-methods


@extend_schema(
    examples=[
        OpenApiExample(name="Email method", value={'email': 'example@example.it'}, request_only=True),
        OpenApiExample(
            name="Email method",
            value={'details': 'Email message with MFA code has been sent.'},
            response_only=True
        ),
        OpenApiExample(name="App method", value={}, request_only=True),
        OpenApiExample(
            name="App method",
            value='OK',
            response_only=True
        )
    ],
    request=[
        inline_serializer(name='Email method', fields={'email': serializers.EmailField()}),
        inline_serializer(name='App method', fields={}),
    ],
    responses={
        200: [
            inline_serializer(name='App/Email method', fields={}),
        ]
    }
)
class MFAMethodActivationView(_MFAMethodActivationView):
    pass


@extend_schema(
    examples=[
        OpenApiExample(name="Email/App method", value={'code': '123456'}, request_only=True),
        OpenApiExample(
            name="Email/App method response",
            value={'backup_codes': ['UFAcHe1mRoJm', 'JYYy5hzBGlVK', 'MCKblDHKLpsy', 'On5uLG3vuQ5r', 'JMlWDiUgxKfE']},
            response_only=True
        )
    ],
    request=[
        inline_serializer(name='Email method', fields={'code': serializers.CharField()}),
        inline_serializer(name='App method', fields={'code': serializers.CharField()}),
    ],
    responses={
        200: [
            inline_serializer(
                name='Email/App method response',
                fields={"backup_codes": serializers.ListSerializer(child=serializers.CharField())}
            ),
        ]
    }
)
class MFAMethodConfirmActivationView(_MFAMethodConfirmActivationView):
    pass


@extend_schema(
    examples=[
        OpenApiExample(name="Email/App method", value={}, request_only=True),
        OpenApiExample(name="Email/App method response", value={}, response_only=True)
    ],
    request=[inline_serializer(name='Email/App method', fields={})],
    responses={204: []}
)
class MFAMethodDeactivationView(_MFAMethodDeactivationView):
    pass


@extend_schema(
    examples=[
        OpenApiExample(name="MFA Enabled", value={'ephemeral_token': 'MyverylOngEphemeralToken'}),
        OpenApiExample(
            name="MFA Disabled",
            value={"refresh": 'MyverylOngRefreshToken', "access": 'MyverylOngAccessToken'},
        ),
    ],
    request={
        200: inline_serializer(
            name='Email method',
            fields={'username': serializers.EmailField(), 'password': serializers.CharField()}
        )
    },
    responses={
        200: [
            inline_serializer(name='MFA Enabled', fields={'ephemeral_token': serializers.CharField()}),
            inline_serializer(
                name='MFA Disabled',
                fields={
                    "refresh": serializers.CharField(required=False),
                    "access": serializers.CharField(required=False),
                }
            ),
        ]
    }
)
class MFAFirstStepJWTView(_MFAFirstStepJWTView):
    pass
